from typing import Tuple, Set, Iterable, List

class GH_ArchiveMessageViewer:
    def __init__(self): ...
    def SetArchive (self, nArchive : GH_Archive) -> None: ...
class GH_DeveloperDetails:
    @property
    def DefaultDeveloperContact () -> str: ...
    @property
    def DeveloperContact () -> str: ...
    @DeveloperContact.setter
    def DeveloperContact (value : str) -> None: ...
